__author__ = "Joseph D. Hughes"
__date__ = "Dec 16, 2022"
__version__ = "0.0.6"
__maintainer__ = "Joseph D. Hughes"
__email__ = "jdhughes@usgs.gov"
__status__ = "Production"
__description__ = """Python tools for MODFLOW development and testing."""
